@@ -437,8 +437,19 @@ def normalize_json_keys(json_obj: dict) -> dict:
     """
     new_json_obj = {}
 
-    for key in json_obj.keys():
-        new_json_obj[normalize_json_key(key)] = json_obj[key]
+    if isinstance(json_obj, list):
+        new_json_obj = []
+
+        for item in json_obj:
+            new_item = {}
+
+            for key in item:
+                new_item[normalize_json_key(key)] = json_obj[key]
+
+            new_json_obj.append(new_item)
+    else:
+        for key in json_obj.keys():
+            new_json_obj[normalize_json_key(key)] = json_obj[key]
 
     return new_json_obj
 
