@@ -132,7 +132,7 @@ class LockssPreservation(models.Model):
         whether the item is fully preserved
         """
         return utils.preservation_status(
-            LockssPreservation, container_title, issn, volume, no=no
+            LockssPreservation, container_title, issn, volume, no=no, year=year
         )
 
     @staticmethod
@@ -245,7 +245,12 @@ class CarinianaPreservation(models.Model):
         whether the item is fully preserved
         """
         return utils.preservation_status(
-            CarinianaPreservation, container_title, issn, volume, no=no
+            CarinianaPreservation,
+            container_title,
+            issn,
+            volume,
+            no=no,
+            year=year,
         )
 
     @staticmethod
@@ -358,7 +363,7 @@ class ClockssPreservation(models.Model):
         whether the item is fully preserved
         """
         return utils.preservation_status(
-            ClockssPreservation, container_title, issn, volume, no=no
+            ClockssPreservation, container_title, issn, volume, no=no, year=year
         )
 
     @staticmethod
@@ -746,6 +751,8 @@ class PorticoPreservation(models.Model):
         # 2013/2014 - v. 2 (1-2)
         volume_regex = r"v\.\s(\d+)"
 
+        year_regex = r"\d{4}"
+
         for pi in preserved_item:
             matches = re.findall(volume_regex, pi.preserved_volumes)
 
@@ -754,6 +761,12 @@ class PorticoPreservation(models.Model):
             if volume in matches:
                 return pi, pi.preserved
 
+            year_matches = re.findall(year_regex, pi.preserved_volumes)
+            year = str(year)
+
+            if year in year_matches:
+                return pi, pi.preserved
+
         return None, False
 
     @staticmethod
